==> strus_0.14.0.orig.tar.gz: strus-0.14.0/src/database_leveldb/database.hpp <==
/*
 * Copyright (c) 2014 Patrick P. Frey
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
#ifndef _STRUS_DATABASE_IMPLEMENTATION_HPP_INCLUDED
#define _STRUS_DATABASE_IMPLEMENTATION_HPP_INCLUDED
#include "strus/databaseInterface.hpp"
#include "databaseClient.hpp"
#include <leveldb/db.h>

namespace strus {

/// \brief Forward declaration
class DatabaseClientInterface;
/// \brief Forward declaration
class DatabaseBackupCursorInterface;
/// \brief Forward declaration
class ErrorBufferInterface;

/// \brief Interface to the create,destroy the key value store database
class Database
	:public DatabaseInterface
{
public:
	explicit Database( ErrorBufferInterface* errorhnd_)
		:m_dbhandle_map( new LevelDbHandleMap()),m_errorhnd(errorhnd_){}

	virtual DatabaseClientInterface* createClient( const std::string& configsource) const;

	virtual bool exists( const std::string& configsource) const;

	virtual bool createDatabase( const std::string& configsource) const;

	virtual bool destroyDatabase( const std::string& configsource) const;

	virtual bool restoreDatabase( const std::string& configsource, DatabaseBackupCursorInterface* backup) const;

	virtual const char* getConfigDescription( const ConfigType& type) const;

	virtual const char** getConfigParameters( const ConfigType& type) const;

private:
	utils::SharedPtr<LevelDbHandleMap> m_dbhandle_map;
	ErrorBufferInterface* m_errorhnd;	///< buffer for reporting errors
};

}//namespace
#endif

==> strus_0.15.5.orig.tar.gz: strus-0.15.5/src/database_leveldb/database.hpp <==
/*
 * Copyright (c) 2014 Patrick P. Frey
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
#ifndef _STRUS_DATABASE_IMPLEMENTATION_HPP_INCLUDED
#define _STRUS_DATABASE_IMPLEMENTATION_HPP_INCLUDED
#include "strus/databaseInterface.hpp"
#include "databaseClient.hpp"
#include "strus/base/shared_ptr.hpp"
#include <leveldb/db.h>

namespace strus {

/// \brief Forward declaration
class DatabaseClientInterface;
/// \brief Forward declaration
class DatabaseBackupCursorInterface;
/// \brief Forward declaration
class ErrorBufferInterface;

/// \brief Interface to the create,destroy the key value store database
class Database
	:public DatabaseInterface
{
public:
	explicit Database( ErrorBufferInterface* errorhnd_)
		:m_dbhandle_map( new LevelDbHandleMap()),m_errorhnd(errorhnd_){}

	virtual DatabaseClientInterface* createClient( const std::string& configsource) const;

	virtual bool exists( const std::string& configsource) const;

	virtual bool createDatabase( const std::string& configsource) const;

	virtual bool destroyDatabase( const std::string& configsource) const;

	virtual bool restoreDatabase( const std::string& configsource, DatabaseBackupCursorInterface* backup) const;

	virtual const char* getConfigDescription( const ConfigType& type) const;

	virtual const char** getConfigParameters( const ConfigType& type) const;

private:
	strus::shared_ptr<LevelDbHandleMap> m_dbhandle_map;
	ErrorBufferInterface* m_errorhnd;	///< buffer for reporting errors
};

}//namespace
#endif
